## Autosubmit contribution guide

**Documentation:** http://autosubmit.readthedocs.io/en/latest/

**GitLab:** https://earth.bsc.es/gitlab/es/autosubmit

**Mailing list:** autosubmit@bsc.es

The production branch generally reflects the Autosubmit release on Pypi, and is considered stable: it should work 'out of the box' for the supported backends. For a list of supported backends, please refer to the documentation.

The master branch (and any other branches than production, for that matter) may not correspond to the published documentation, and specifically may have dependencies which need to be resolved manually. Please contact us over the mailing list if you need advice on the usage of any non-production branch.